# HangMan
A character user interface of the  popular game hangman 

This repository provides code for my [blog](https://attackonalgorithms.wordpress.com/2019/10/24/slightly-non-trivial-implementation-of-cli-hangman-a-hands-on-python-tutorial/) 
